/* This is a GENERATED file. */
/* Generated data (by glib-mkenums) */

#ifndef __GWY_APP_TYPES_H__
#define __GWY_APP_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

GType gwy_app_what_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_APP_WHAT (gwy_app_what_get_type())

GType gwy_data_item_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_DATA_ITEM (gwy_data_item_get_type())

GType gwy_visibility_reset_type_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_VISIBILITY_RESET_TYPE (gwy_visibility_reset_type_get_type())

GType gwy_menu_sens_flags_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_MENU_SENS_FLAGS (gwy_menu_sens_flags_get_type())

GType gwy_text_header_error_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_TEXT_HEADER_ERROR (gwy_text_header_error_get_type())

GType gwy_plain_tool_changed_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_PLAIN_TOOL_CHANGED (gwy_plain_tool_changed_get_type())

GType gwy_app_settings_error_get_type(void) G_GNUC_CONST;
#define GWY_TYPE_APP_SETTINGS_ERROR (gwy_app_settings_error_get_type())

G_END_DECLS

#endif /* __GWY_APP_TYPES_H__ */

/* Generated data ends here */

